import React from 'react';
import Document, { Html, Head, Main, NextScript} from 'next/document';
import {ServerStyleSheets} from '@material-ui/core/styles';

class MyDocument extends Document {
	render() {
		return (
        <Html>
		<Head>
			<link rel="stylesheet" href="https://fonts.googleapis.com/icon?family=Material+Icons"/>
			<link rel="icon" href="/static/favicon.ico"/>
		</Head>
		<body>
		<Main/>
		<NextScript/>
		</body>
		</Html>);
	}
}

MyDocument.getInitialProps = async ctx => {
	// Resolution order
	//
	// On the server:
	// 1. app.getInitialProps
	// 2. page.getInitialProps
	// 3. document.getInitialProps
	// 4. app.render
	// 5. page.render
	// 6. document.render
	//
	// On the server with error:
	// 1. document.getInitialProps
	// 2. app.render
	// 3. page.render
	// 4. document.render
	//
	// On the client
	// 1. app.getInitialProps
	// 2. page.getInitialProps
	// 3. app.render
	// 4. page.render

	// Render app and page and get the context of the page with collected side effects.
	const sheets = new ServerStyleSheets();
	const originalRenderPage = ctx.renderPage;

	ctx.renderPage = () => originalRenderPage({
		enhanceApp: App => props => sheets.collect(<App {...props} />),
	});

	const initialProps = await Document.getInitialProps(ctx);

	return {
		...initialProps, // Styles fragment is rendered after the app and page rendering finish.
		styles: (<React.Fragment>
			{initialProps.styles}
			{sheets.getStyleElement()}
		</React.Fragment>),
	};
};

export default MyDocument;